The ``woehler`` module
######################

Module description
==================

.. toctree::
   :maxdepth: 1

   woehler/index


Fatigue data handling
=====================

.. toctree::
   :maxdepth: 1

   woehler/fatigue_data


Analyzers
=========

.. toctree::
   :maxdepth: 1

   woehler/elementary
   woehler/probit
   woehler/maxlikeinf
   woehler/maxlikefull
   woehler/bayesian


Helpers
=======

.. toctree::
   :maxdepth: 1

   woehler/pearl_chain
   woehler/likelihood
